# Backea - P2P Backup Made Simple

Backea is a peer-to-peer (P2P) backup tool that seamlessly integrates multiple backup backends like Kopia, Borg, and more in the future. It is designed to work across containers and multiple remote machines, ensuring that each system can have multiple backup destinations using different backends for different needs—effortlessly.

![Backea](img/img.png)

## 🚀 Why Backea?

### 🔹 One-Click Restores
No more hassle. Restore or download your data with a single click on the web UI.

### 🔹 True 3-2-1 Backup Strategy
Backea automatically ensures redundancy and safety for your critical data, following the best practice of having at least three copies, stored on two different media, with at least one copy off-site.

### 🔹 Why Use Different Backup Backends?
Different backup tools are optimized for different use cases:
- **Kopia**: Provides encryption and deduplication, ideal for securing sensitive data like personal photos and documents.
- **Borg**: Offers deduplication without encryption, making it a great choice for heavy workloads like GitLab repositories or Minecraft servers where encryption isn't necessary.
- More incoming


## 📦 Features
- **P2P Backup Architecture** – Backup across your remote machines seamlessly.
- **Multi-Backend Support** – Use multiple backup backends for different needs.
- **Containerized Deployment** – Easily deploy and run Backea in a containerized environment.
- **Automatic Backup Scheduling** – Ensure regular backups without manual intervention.
- **Effortless Restoration** – Restore data with a single click.
- **Secure & Efficient** – Leverage encryption and deduplication for optimized storage.

## 🛠 Installation & Usage

### Prerequisites
- Docker (or a compatible container runtime)

### Installation
```sh
git clone https://gitea.maric.ro/sirir/backea
cp .env.example .env
docker compose up -d
```

### Configuration
1. Define your backup destinations and backends in the configuration file.
2. Set up backup schedules and retention policies.
3. Start Backea and let it handle the backups for you.

### Running Backups
To trigger a backup manually, use:
```sh
docker exec -it backea /app/backup-performer
```

### Restoring Data
To restore data from a backup:
```sh
docker exec -it backea restore --destination /path/to/restore
```

### Accessing Backea
Visit [http://localhost:21311](http://localhost:21311) to manage your backups via the Backea web interface.

### ⚠️ 
- **Don't forget edit the config.yml!**
- **Don't forget to mount the repositories!**
- **Don't forget restart the container after a config change!**

## 📜 License
Backea is licensed under the [Creative Commons Attribution-NonCommercial (CC BY-NC) ](LICENSE).

## 📧 Contact & Support
For any questions, feature requests, or issues, feel free to or reach out via [backea@maric.ro](mailto:backea@maric.ro).

---

### ⭐ If you find Backea useful, please consider giving a star!

